@@ -3,6 +3,7 @@ import os.path
 import random
 import string
 import time
+import traceback
 import uuid
 from functools import reduce
 from itertools import groupby
@@ -40,7 +41,7 @@ def remove_list_dict_duplicate(list_dict_data):
     return reduce(lambda x, y: x if y in x else x + [y], [[], ] + list_dict_data)
 
 
-def retry(func, params: Union[dict, list, tuple], check_func, num=1):
+def retry(func, params: Union[dict, list, tuple, None] = None, check_func: callable = None, num: int = 1):
     """
     执行失败重试
     :param func: 要执行的函数
@@ -61,11 +62,14 @@ def retry(func, params: Union[dict, list, tuple], check_func, num=1):
                     break
             else:
                 result = func()
-            flag = check_func(result)
-            if flag:
-                break
+            if check_func:
+                flag = check_func(result)
+                if flag:
+                    break
         except Exception as e:
-            logging.error(f"error={e}")
+            traceback.print_exc()
+            if i == num - 1:
+                raise e
     return result
 
 
